multivitamin.applications.text package
======================================

Module contents
---------------

.. automodule:: multivitamin.applications.text
   :members:
   :undoc-members:
   :show-inheritance:
